@@ -46,7 +46,7 @@ yaml.add_representer(np.str_,
 # Display deprecation warnings
 warnings.filterwarnings("always", category=DeprecationWarning, module="hepdata_lib")
 
-__version__ = "0.10.0"
+__version__ = "0.10.1"
 
 class AdditionalResourceMixin(object):
     """Functionality related to additional materials."""
@@ -538,7 +538,7 @@ class Submission(AdditionalResourceMixin):
             files = files + table.files_to_copy
         return files
 
-    def create_files(self, outdir=".", validate=True, remove_old=True):
+    def create_files(self, outdir=".", validate=True, remove_old=False):
         """
         Create the output files.
 
